@@ -773,10 +773,52 @@ action_about (GSimpleAction *action,
                          NULL);
 }
 
+static void
+action_screen_shot (GSimpleAction *action,
+                    GVariant *parameter,
+                    gpointer user_data)
+{
+  ScreenshotApplication *self = SCREENSHOT_APPLICATION (user_data);
+
+  screenshot_config_parse_command_line (FALSE, /* clipboard */
+                                        FALSE,  /* window */
+                                        FALSE, /* area */
+                                        FALSE, /* include border */
+                                        FALSE, /* disable border */
+                                        FALSE, /* include pointer */
+                                        NULL,  /* border effect */
+                                        0,     /* delay */
+                                        FALSE, /* interactive */
+                                        NULL); /* file */
+  screenshot_start (self);
+}
+
+static void
+action_window_shot (GSimpleAction *action,
+                    GVariant *parameter,
+                    gpointer user_data)
+{
+  ScreenshotApplication *self = SCREENSHOT_APPLICATION (user_data);
+
+  screenshot_config_parse_command_line (FALSE, /* clipboard */
+                                        TRUE,  /* window */
+                                        FALSE, /* area */
+                                        FALSE, /* include border */
+                                        FALSE, /* disable border */
+                                        FALSE, /* include pointer */
+                                        NULL,  /* border effect */
+                                        0,     /* delay */
+                                        FALSE, /* interactive */
+                                        NULL); /* file */
+  screenshot_start (self);
+}
+
 static GActionEntry action_entries[] = {
   { "about", action_about, NULL, NULL, NULL },
   { "help", action_help, NULL, NULL, NULL },
-  { "quit", action_quit, NULL, NULL, NULL }
+  { "quit", action_quit, NULL, NULL, NULL },
+  { "screen-shot", action_screen_shot, NULL, NULL, NULL },
+  { "window-shot", action_window_shot, NULL, NULL, NULL }
 };
 
 static void
